diff --git a/README.md b/README.md
index ade1f5c..4507844 100644
--- a/README.md
+++ b/README.md
@@ -141,16 +141,6 @@ MySpider().start()
TikHub.io provides 900+ stable APIs across 16+ platforms including TikTok, X, YouTube & Instagram, with 40M+ datasets.
Also offers DISCOUNTED AI models - Claude, GPT, GEMINI & more up to 71% off.
-
-
-
-
-
- |
-
- Nsocks provides fast Residential and ISP proxies for developers and scrapers. Global IP coverage, high anonymity, smart rotation, and reliable performance for automation and data extraction. Use Xcrawl to simplify large-scale web crawling.
- |
-
|
@@ -189,7 +179,7 @@ MySpider().start()
|
- 9Proxy provides residential proxies from just $0.015/IP or $0.68/GB. 20M+ IPs across 90+ countries. Sticky or rotating sessions, managed from desktop or mobile app.
+ 9Proxy provides residential proxies from just $0.018/IP or $0.68/GB. 20M+ IPs across 90+ countries. Sticky or rotating sessions, managed from desktop or mobile app.
|
diff --git a/docs/README_AR.md b/docs/README_AR.md
index f798baa..2070bc9 100644
--- a/docs/README_AR.md
+++ b/docs/README_AR.md
@@ -137,16 +137,6 @@ MySpider().start()
TikHub.io يوفر أكثر من 900 واجهة API مستقرة عبر أكثر من 16 منصة تشمل TikTok و X و YouTube و Instagram، مع أكثر من 40 مليون مجموعة بيانات.
يقدم أيضاً نماذج ذكاء اصطناعي بأسعار مخفضة - Claude و GPT و GEMINI والمزيد بخصم يصل إلى 71%.
-
-
-
-
-
- |
-
- Nsocks يوفر بروكسيات سكنية و ISP سريعة للمطورين والسكرابرز. تغطية IP عالمية، إخفاء هوية عالي، تدوير ذكي، وأداء موثوق للأتمتة واستخراج البيانات. استخدم Xcrawl لتبسيط زحف الويب على نطاق واسع.
- |
-
|
@@ -185,7 +175,7 @@ MySpider().start()
|
- يوفر 9Proxy بروكسيات سكنية بدءًا من 0.015 دولار فقط لكل IP أو 0.68 دولار لكل جيجابايت. أكثر من 20 مليون عنوان IP في أكثر من 90 دولة. جلسات ثابتة أو متناوبة، تتم إدارتها من تطبيق سطح المكتب أو الجوال.
+ يوفر 9Proxy بروكسيات سكنية بدءًا من 0.018 دولار فقط لكل IP أو 0.68 دولار لكل جيجابايت. أكثر من 20 مليون عنوان IP في أكثر من 90 دولة. جلسات ثابتة أو متناوبة، تتم إدارتها من تطبيق سطح المكتب أو الجوال.
|
diff --git a/docs/README_CN.md b/docs/README_CN.md
index 62b4747..0750bcc 100644
--- a/docs/README_CN.md
+++ b/docs/README_CN.md
@@ -137,16 +137,6 @@ MySpider().start()
TikHub.io 提供覆盖 16+ 平台(包括 TikTok、X、YouTube 和 Instagram)的 900+ 稳定 API,拥有 4000 万+ 数据集。
还提供优惠 AI 模型 - Claude、GPT、GEMINI 等,最高优惠 71%。
-
-
-
-
-
- |
-
- Nsocks 提供面向开发者和爬虫的快速住宅和 ISP 代理。全球 IP 覆盖、高匿名性、智能轮换,以及可靠的自动化和数据提取性能。使用 Xcrawl 简化大规模网页爬取。
- |
-
|
@@ -185,7 +175,7 @@ MySpider().start()
|
- 9Proxy 提供住宅代理,价格低至每个 IP 仅 $0.015 或每 GB $0.68。覆盖 90+ 国家/地区的 2000 万+ IP。支持固定或轮换会话,可通过桌面或移动应用进行管理。
+ 9Proxy 提供住宅代理,价格低至每个 IP 仅 $0.018 或每 GB $0.68。覆盖 90+ 国家/地区的 2000 万+ IP。支持固定或轮换会话,可通过桌面或移动应用进行管理。
|
diff --git a/docs/README_DE.md b/docs/README_DE.md
index e3fb3e6..ac6e533 100644
--- a/docs/README_DE.md
+++ b/docs/README_DE.md
@@ -137,16 +137,6 @@ MySpider().start()
TikHub.io bietet über 900 stabile APIs auf mehr als 16 Plattformen, darunter TikTok, X, YouTube und Instagram, mit über 40 Mio. Datensätzen.
Bietet außerdem vergünstigte KI-Modelle - Claude, GPT, GEMINI und mehr mit bis zu 71% Rabatt.
-
-
-
-
-
- |
-
- Nsocks bietet schnelle Residential- und ISP-Proxies für Entwickler und Scraper. Globale IP-Abdeckung, hohe Anonymität, intelligente Rotation und zuverlässige Leistung für Automatisierung und Datenextraktion. Verwenden Sie Xcrawl, um großflächiges Web-Crawling zu vereinfachen.
- |
-
|
@@ -185,7 +175,7 @@ MySpider().start()
|
- 9Proxy bietet Residential-Proxys ab nur 0,015 $/IP oder 0,68 $/GB. Über 20 Mio. IPs in mehr als 90 Ländern. Sticky oder rotierende Sessions, verwaltet über die Desktop- oder Mobile-App.
+ 9Proxy bietet Residential-Proxys ab nur 0,018 $/IP oder 0,68 $/GB. Über 20 Mio. IPs in mehr als 90 Ländern. Sticky oder rotierende Sessions, verwaltet über die Desktop- oder Mobile-App.
|
diff --git a/docs/README_ES.md b/docs/README_ES.md
index 05d49a0..1af1f9a 100644
--- a/docs/README_ES.md
+++ b/docs/README_ES.md
@@ -137,16 +137,6 @@ MySpider().start()
TikHub.io ofrece más de 900 APIs estables en más de 16 plataformas, incluyendo TikTok, X, YouTube e Instagram, con más de 40M de conjuntos de datos.
También ofrece modelos de IA con descuento - Claude, GPT, GEMINI y más con hasta un 71% de descuento.
-
-
-
-
-
- |
-
- Nsocks ofrece proxies residenciales e ISP rápidos para desarrolladores y scrapers. Cobertura IP global, alto anonimato, rotación inteligente y rendimiento fiable para automatización y extracción de datos. Usa Xcrawl para simplificar el crawling web a gran escala.
- |
-
|
@@ -185,7 +175,7 @@ MySpider().start()
|
- 9Proxy ofrece proxies residenciales desde solo $0,015/IP o $0,68/GB. Más de 20 millones de IPs en más de 90 países. Sesiones fijas o rotativas, gestionadas desde la aplicación de escritorio o móvil.
+ 9Proxy ofrece proxies residenciales desde solo $0,018/IP o $0,68/GB. Más de 20 millones de IPs en más de 90 países. Sesiones fijas o rotativas, gestionadas desde la aplicación de escritorio o móvil.
|
diff --git a/docs/README_FR.md b/docs/README_FR.md
index d1dc0fd..c6d76ed 100644
--- a/docs/README_FR.md
+++ b/docs/README_FR.md
@@ -137,16 +137,6 @@ MySpider().start()
TikHub.io propose plus de 900 APIs stables sur plus de 16 plateformes, dont TikTok, X, YouTube et Instagram, avec plus de 40M de jeux de données.
Propose également des modèles IA à prix réduit - Claude, GPT, GEMINI et plus, jusqu'à 71% de réduction.
-
-
-
-
-
- |
-
- Nsocks fournit des proxies résidentiels et ISP rapides pour les développeurs et les scrapeurs. Couverture IP mondiale, anonymat élevé, rotation intelligente et performances fiables pour l'automatisation et l'extraction de données. Utilisez Xcrawl pour simplifier le crawling web à grande échelle.
- |
-
|
@@ -185,7 +175,7 @@ MySpider().start()
|
- 9Proxy propose des proxys résidentiels à partir de seulement 0,015 $/IP ou 0,68 $/Go. Plus de 20 millions d'IPs dans plus de 90 pays. Sessions fixes ou rotatives, gérées depuis l'application de bureau ou mobile.
+ 9Proxy propose des proxys résidentiels à partir de seulement 0,018 $/IP ou 0,68 $/Go. Plus de 20 millions d'IPs dans plus de 90 pays. Sessions fixes ou rotatives, gérées depuis l'application de bureau ou mobile.
|
diff --git a/docs/README_JP.md b/docs/README_JP.md
index 9d4db25..dcf44fc 100644
--- a/docs/README_JP.md
+++ b/docs/README_JP.md
@@ -137,16 +137,6 @@ MySpider().start()
TikHub.io は TikTok、X、YouTube、Instagram を含む 16 以上のプラットフォームで 900 以上の安定した API を提供し、4,000 万以上のデータセットを保有。
さらに 割引 AI モデルも提供 - Claude、GPT、GEMINI など最大 71% オフ。
-
-
-
-
-
- |
-
- Nsocks は開発者やスクレイパー向けの高速なレジデンシャルおよび ISP プロキシを提供。グローバル IP カバレッジ、高い匿名性、スマートなローテーション、自動化とデータ抽出のための信頼性の高いパフォーマンス。Xcrawl で大規模ウェブクローリングを簡素化。
- |
-
|
@@ -185,7 +175,7 @@ MySpider().start()
|
- 9Proxy はIPあたり $0.015 またはGBあたり $0.68 からの住宅用プロキシを提供します。90カ国以上で2,000万以上のIPを保有。固定セッションまたはローテーションセッションをデスクトップまたはモバイルアプリで管理できます。
+ 9Proxy はIPあたり $0.018 またはGBあたり $0.68 からの住宅用プロキシを提供します。90カ国以上で2,000万以上のIPを保有。固定セッションまたはローテーションセッションをデスクトップまたはモバイルアプリで管理できます。
|
diff --git a/docs/README_KR.md b/docs/README_KR.md
index 4a4ef26..18d2e05 100644
--- a/docs/README_KR.md
+++ b/docs/README_KR.md
@@ -137,16 +137,6 @@ MySpider().start()
TikHub.io는 TikTok, X, YouTube, Instagram 등 16개 이상 플랫폼에서 900개 이상의 안정적인 API를 제공하며, 4,000만 이상의 데이터셋을 보유하고 있습니다.
할인된 AI 모델도 제공 - Claude, GPT, GEMINI 등 최대 71% 할인.
-
-
-
-
-
- |
-
- Nsocks는 개발자와 스크레이퍼를 위한 빠른 레지덴셜 및 ISP 프록시를 제공합니다. 글로벌 IP 커버리지, 높은 익명성, 스마트 로테이션, 자동화와 데이터 추출을 위한 안정적인 성능. Xcrawl로 대규모 웹 크롤링을 간소화하세요.
- |
-
|
@@ -185,7 +175,7 @@ MySpider().start()
|
- 9Proxy는 IP당 $0.015 또는 GB당 $0.68의 저렴한 가격부터 시작하는 주거용 프록시를 제공합니다. 90개국 이상에서 2천만 개 이상의 IP를 보유하고 있으며, 고정 또는 회전 세션을 데스크톱이나 모바일 앱에서 관리할 수 있습니다.
+ 9Proxy는 IP당 $0.018 또는 GB당 $0.68의 저렴한 가격부터 시작하는 주거용 프록시를 제공합니다. 90개국 이상에서 2천만 개 이상의 IP를 보유하고 있으며, 고정 또는 회전 세션을 데스크톱이나 모바일 앱에서 관리할 수 있습니다.
|
diff --git a/docs/README_PT_BR.md b/docs/README_PT_BR.md
index 23ce34b..4c7f617 100644
--- a/docs/README_PT_BR.md
+++ b/docs/README_PT_BR.md
@@ -139,16 +139,6 @@ MySpider().start()
TikHub.io oferece mais de 900 APIs estáveis em mais de 16 plataformas, incluindo TikTok, X, YouTube e Instagram, com mais de 40M de datasets.
Também oferece modelos de IA com desconto - Claude, GPT, GEMINI e mais com até 71% de desconto.
-
-
-
-
-
- |
-
- Nsocks fornece proxies residenciais e ISP rápidos para desenvolvedores e scrapers. Cobertura global de IPs, alto anonimato, rotação inteligente e desempenho confiável para automação e extração de dados. Use o Xcrawl para simplificar o crawling web em larga escala.
- |
-
|
@@ -187,7 +177,7 @@ MySpider().start()
|
- 9Proxy oferece proxies residenciais a partir de apenas $0,015/IP ou $0,68/GB. Mais de 20M de IPs em mais de 90 países. Sessões fixas ou rotativas, gerenciadas pelo aplicativo desktop ou móvel.
+ 9Proxy oferece proxies residenciais a partir de apenas $0,018/IP ou $0,68/GB. Mais de 20M de IPs em mais de 90 países. Sessões fixas ou rotativas, gerenciadas pelo aplicativo desktop ou móvel.
|
diff --git a/docs/README_RU.md b/docs/README_RU.md
index 7660551..4dde2b9 100644
--- a/docs/README_RU.md
+++ b/docs/README_RU.md
@@ -140,16 +140,6 @@ MySpider().start()
TikHub.io предоставляет более 900 стабильных API на 16+ платформах, включая TikTok, X, YouTube и Instagram, с более чем 40 млн наборов данных.
Также предлагает AI-модели со скидкой - Claude, GPT, GEMINI и другие со скидкой до 71%.
-
-
-
-
-
- |
-
- Nsocks предоставляет быстрые резидентные и ISP прокси для разработчиков и скраперов. Глобальное покрытие IP, высокая анонимность, умная ротация и надёжная производительность для автоматизации и извлечения данных. Используйте Xcrawl для упрощения масштабного веб-краулинга.
- |
-
|
@@ -188,7 +178,7 @@ MySpider().start()
|
- 9Proxy предоставляет резидентные прокси всего от $0,015 за IP или $0,68 за ГБ. Более 20 млн IP в 90+ странах. Закреплённые или ротационные сессии, управление через настольное или мобильное приложение.
+ 9Proxy предоставляет резидентные прокси всего от $0,018 за IP или $0,68 за ГБ. Более 20 млн IP в 90+ странах. Закреплённые или ротационные сессии, управление через настольное или мобильное приложение.
|
diff --git a/docs/donate.md b/docs/donate.md
index 0228bd6..dbaab5a 100644
--- a/docs/donate.md
+++ b/docs/donate.md
@@ -1,3 +1,5 @@
+# Support and Advertisement
+
I've been creating all of these projects in my spare time and have invested considerable resources & effort in providing them to the community for free. By becoming a sponsor, you'd be directly funding my coffee reserves, helping me fulfill my responsibilities, and enabling me to continuously update existing projects and potentially create new ones.
You can sponsor me directly through the [GitHub Sponsors program](https://github.com/sponsors/D4Vinci) or [Buy Me a Coffee](https://buymeacoffee.com/d4vinci).
diff --git a/docs/index.md b/docs/index.md
index b9ea5ca..fdae518 100644
--- a/docs/index.md
+++ b/docs/index.md
@@ -71,9 +71,6 @@ MySpider().start()
-
-
-
diff --git a/images/nsocks.png b/images/nsocks.png
deleted file mode 100644
index 120a06c..0000000
Binary files a/images/nsocks.png and /dev/null differ
diff --git a/scrapling/cli.py b/scrapling/cli.py
index 47056d9..4b9eb86 100644
--- a/scrapling/cli.py
+++ b/scrapling/cli.py
@@ -2,6 +2,7 @@ from pathlib import Path
from subprocess import check_output
from sys import executable as python_executable
+from scrapling import __version__
from scrapling.core.utils import log
from scrapling.engines.toolbelt.custom import Response
from scrapling.core.utils._shell import _CookieParser, _ParseHeaders
@@ -10,7 +11,7 @@ from scrapling.core._types import List, Optional, Dict, Tuple, Any, Callable
from orjson import loads as json_loads, JSONDecodeError
try:
- from click import command, option, Choice, group, argument
+ from click import command, option, Choice, group, argument, version_option
except (ImportError, ModuleNotFoundError) as e:
raise ModuleNotFoundError(
"You need to install scrapling with any of the extras to enable Shell commands. See: https://scrapling.readthedocs.io/en/latest/#installation"
@@ -650,6 +651,7 @@ def stealthy_fetch(
@group()
+@version_option(version=__version__, prog_name="Scrapling")
def main():
pass
diff --git a/tests/cli/test_cli.py b/tests/cli/test_cli.py
index 39345d0..642699d 100644
--- a/tests/cli/test_cli.py
+++ b/tests/cli/test_cli.py
@@ -4,8 +4,9 @@ from unittest.mock import patch, MagicMock
import pytest_httpbin
from scrapling.parser import Selector
+from scrapling import __version__
from scrapling.cli import (
shell, mcp, get, post, put, delete, fetch, stealthy_fetch
)
@@ -32,6 +33,12 @@ class TestCLI:
def runner(self):
return CliRunner()
+ def test_version_flag(self, runner):
+ """Test that the --version flag prints the Scrapling version and exits"""
+ result = runner.invoke(main, ['--version'])
+ assert result.exit_code == 0
+ assert result.output.strip() == f'Scrapling, version {__version__}'
+
def test_shell_command(self, runner):
"""Test shell command"""
with patch('scrapling.core.shell.CustomShell') as mock_shell:
@@ -4,8 +4,9 @@ from unittest.mock import patch, MagicMock
from scrapling.cli import (
- shell, mcp, get, post, put, delete, fetch, stealthy_fetch
+ main, shell, mcp, get, post, put, delete, fetch, stealthy_fetch
)